@@ -8,8 +8,6 @@ context("test printing")
 # writeLines(connectapi:::generate_R6_print_output(), rprojroot::find_testthat_root_file("test-print-output.txt"))
 
 test_that("output matches previous expectation", {
-  expect_equal(
-    generate_R6_print_output(),
-    readLines(rprojroot::find_testthat_root_file("test-print-output.txt"))
-  )
+  local_edition(3)
+  expect_snapshot(generate_R6_print_output())
 })
